Thank you for your interest to contribute to `acados`.
All contributions are licensed under the terms of the [2-Clause BSD License](./LICENSE).
By making a contribution to `acados` you certify that you have the right to submit the code that you are contributing to the project according to the [Developer Certificate of Origin (DCO)](https://developercertificate.org/).
Contributions are welcome via pull requests on Github.
